@@ -296,7 +296,8 @@ static void _write_nodes(GObject *object, xmlNodePtr node)
 				_object = g_value_get_object (&pval);
 				
 				if (_object) {
-
+					/* Add reference to object. It'll be unref in g_value_unset */
+					g_object_ref (_object);
 					op_node = xmlNewNode(NULL, BAD_CAST pspec[i]->name);
 					_write_nodes(_object, op_node);
 					xmlAddChild(node, op_node);
@@ -320,7 +321,6 @@ static void _write_nodes(GObject *object, xmlNodePtr node)
 							pspec[i]->name, g_type_name (pspec[i]->value_type)); 
 				}
 		}
-
 		g_value_unset(&pval);
 	}
 
@@ -752,13 +752,15 @@ GObject **midgard_core_object_from_xml(MidgardConnection *mgd,
 		
 		_objects = g_new(MidgardObject *, _n_nodes+1);
 		_n_nodes = 0;
-		
-		for(; olist ; olist = olist->next){
-			_objects[_n_nodes] = olist->data;
+	
+		GSList *l = NULL;	
+		for(l = olist; l != NULL ; l = l->next){
+			_objects[_n_nodes] = l->data;
 			_n_nodes++;
 		}
 
-		g_slist_free(olist);
+		if (olist)
+			g_slist_free(olist);
 		_objects[_n_nodes] = NULL;
 	}
 
@@ -855,3 +857,26 @@ midgard_core_object_property_refuse_private (MidgardConnection *mgd, MgdSchemaTy
 	MIDGARD_ERRNO_SET (mgd, MGD_ERR_ACCESS_DENIED);
 	return TRUE;
 }
+
+/* Returns field name of 'deleted' property or NULL if none is defined */
+const gchar*
+midgard_core_object_get_deleted_field(MidgardDBObjectClass *dbklass)
+{
+	g_return_val_if_fail (dbklass != NULL, NULL);
+
+	GParamSpec *pspec = NULL;
+	MidgardMetadataClass *mklass = MGD_DBCLASS_METADATA_CLASS (dbklass);
+
+	if (mklass == NULL) {
+		pspec = g_object_class_find_property (G_OBJECT_CLASS (dbklass), METADATA_PROPERTY_DELETED);
+		if (pspec)
+			midgard_core_class_get_property_colname (dbklass, METADATA_PROPERTY_DELETED);
+		return NULL;
+	}
+
+	pspec = g_object_class_find_property (G_OBJECT_CLASS (mklass), METADATA_PROPERTY_DELETED);
+	if (pspec)
+		return METADATA_FIELD_DELETED;
+
+	return NULL;
+}
