@@ -185,15 +185,15 @@ GdaDataModel *midgard_core_query_get_model(MidgardConnection *mgd, const gchar *
 	gda_command_free(command);
 #endif
 
+	if (MGD_CNC_DEBUG (mgd))
+		g_debug("Model query = %s", query);
+
 	if (lerror) {
 	
 		g_warning("Model query failed: %s", lerror && lerror->message ? lerror->message : "No description");
 		g_error_free(lerror);
 	}
 
-	if (MGD_CNC_DEBUG (mgd))
-		g_debug("Model query = %s", query);
-
 	/* This is query error */
 	if(!model) 
 		return NULL;
@@ -679,8 +679,6 @@ __add_metadata_parameters (MidgardDBObject *dbobject, MidgardDBObjectClass *klas
 	g_free (pspecs);
 }
 
-#ifdef HAVE_LIBGDA_4
-
 gboolean 
 midgard_core_query_create_dbobject_record (MidgardDBObject *object)
 {
@@ -734,157 +732,6 @@ midgard_core_query_create_dbobject_record (MidgardDBObject *object)
 	return inserted;
 }
 
-#else 
-
-gboolean 
-midgard_core_query_create_dbobject_record (MidgardDBObject *object)
-{
-	g_return_val_if_fail (object != NULL, FALSE);
-	
-	GdaConnection *cnc = (MGD_OBJECT_CNC (object))->priv->connection;
-	gboolean bv;
-
-	MidgardDBObjectClass *klass = g_type_class_peek (G_OBJECT_TYPE (object));
-	if (!klass) {
-
-		g_warning ("Can not find class pointer for %s instance", G_OBJECT_TYPE_NAME (object));
-		return FALSE;
-	}
-
-	const gchar *table = midgard_core_class_get_table (klass);
-	if (!table) {
-		
-		g_warning ("Empty table for %s class", G_OBJECT_TYPE_NAME (object));
-		return FALSE;
-	}
-
-	guint n_prop;
-	guint i;
-	GParamSpec **pspecs = g_object_class_list_properties (G_OBJECT_CLASS (klass), &n_prop);
-
-	if (!pspecs) {
-		
-		g_warning ("Properties not registered for %s class", G_OBJECT_TYPE_NAME (object));
-		return FALSE;
-	}
-
-	GdaDict *dict = gda_dict_new ();
-        gda_dict_set_connection (dict , (MGD_OBJECT_CNC (object))->priv->connection);
-
-	GString *sqlquery = g_string_new ("INSERT INTO ");
-	g_string_append_printf (sqlquery, "%s ( ", table);
-
-	GString *values = g_string_new (" VALUES( ");
-	MgdSchemaPropertyAttr *prop_attr = NULL;
-
-	/* Create parameters from properties */
-	GParameter *parameters = g_new0 (GParameter, n_prop);
-
-	for (i = 0; i < n_prop; i++) {
-		
-		GValue value = {0, };
-		g_value_init (&value, pspecs[i]->value_type);
-		g_object_get_property (G_OBJECT (object), pspecs[i]->name, &value);
-
-		/* Convert boolean to integer, it's safe for SQLite at least */
-		if (pspecs[i]->value_type == G_TYPE_BOOLEAN) {
-
-			bv = g_value_get_boolean (&value);
-			g_value_unset (&value);
-
-			g_value_init (&value, G_TYPE_UINT);
-			g_value_set_uint (&value, bv ? 1 : 0);
-		}
-
-		/* Map property to storage field */
-		prop_attr = midgard_core_class_get_property_attr (klass, pspecs[i]->name);
-		parameters[i].name = prop_attr->field;
-		parameters[i].value = (const GValue)value;
-		g_string_append_printf (sqlquery, "%s %s", i > 0 ? "," : "", prop_attr->field);
-		_add_value_type (values, parameters[i].name, &parameters[i].value, i > 0 ? TRUE : FALSE);
-		g_value_unset (&value);
-	}
-
-	g_string_append_printf (sqlquery, " ) %s )", values->str);
-
-	GError *error = NULL;
-        GdaQuery *query = gda_query_new_from_sql (dict, sqlquery->str, &error);
-
-	g_string_free (sqlquery, TRUE);
-	g_string_free (values, TRUE);
-
-	if (query) 
-		g_debug("%s", gda_query_get_sql_text(query));
-
-	if (!query || error) {
-		g_warning ("Failed to create new query from string. %s", error && error->message ? error->message : "Unknown reason");
-
-		if (query)
-			g_object_unref (query);
-
-		g_object_unref (dict);
-		g_free (pspecs);
-		
-		return FALSE;
-	}
-
-	GdaParameterList *plist = gda_query_get_parameter_list (query);
-	GdaParameter *param;
-
-	for (i = 0; i < n_prop; i++) {
-
-		/* Map property to storage field */
-		prop_attr = midgard_core_class_get_property_attr (klass, pspecs[i]->name);
-		param = gda_parameter_list_find_param (plist, prop_attr->field);
-		GValue val = {0, };
-		g_value_init (&val, pspecs[i]->value_type);
-		g_object_get_property (G_OBJECT(object), pspecs[i]->name, &val);
-
-		/* Convert boolean to integer, it's safe for SQLite at least */
-		if (pspecs[i]->value_type == G_TYPE_BOOLEAN) {
-
-			bv = g_value_get_boolean (&val);
-			g_value_unset (&val);
-
-			g_value_init (&val, G_TYPE_UINT);
-			g_value_set_uint (&val, bv ? 1 : 0);
-		}
-
-		gda_parameter_set_value (param, (const GValue*) &val);
-		g_value_unset (&val);
-	}
-
-	gda_connection_clear_events_list (cnc);
-
-	g_free (pspecs);
-	g_object_unref (dict);
-
-	if (error)
-		g_clear_error (&error);
-	error = NULL;
-
-	/* TODO , debug query */
-	GdaObject *res_object = gda_query_execute (query, plist, FALSE, &error);
-
-	g_object_unref (query);
-	g_object_unref (plist);
-
-	if (!res_object)
-		return FALSE;
-
-	g_object_unref (res_object);
-
-	if (error) {
-
-		g_warning ("Failed to create object record. %s", error && error->message ? error->message : "Unknown reason");
-		return FALSE;
-	}
-
-	return TRUE;
-}
-
-#endif /* HAVE_LIBGDA_4 */
-
 gboolean 
 midgard_core_query_update_dbobject_record (MidgardDBObject *object)
 {
@@ -2274,7 +2121,11 @@ gboolean midgard_core_query_update_class_storage(MidgardConnection *mgd, Midgard
 	gchar **spltd;	
 
 	for (i = 0; i < n_prop; i++) {
-	
+
+		/* Ignore properties of object type */
+		if (G_TYPE_FUNDAMENTAL (pspecs[i]->value_type) == G_TYPE_OBJECT)
+			continue;
+
 		nick = midgard_core_class_get_property_tablefield
 			(MIDGARD_DBOBJECT_CLASS(klass), pspecs[i]->name);
 
@@ -2576,8 +2427,10 @@ midgard_core_dbjoin_new(void)
 	mdbj->klass = NULL;
 	mdbj->left_table = NULL;
 	mdbj->left_field = NULL;
+	mdbj->left_klass = NULL;
 	mdbj->right_table = NULL;
 	mdbj->right_field = NULL;
+	mdbj->right_klass = NULL;
 	mdbj->left_tablefield = NULL;
 	mdbj->right_tablefield = NULL;
 
