@@ -52,8 +52,10 @@ struct _MidgardDBJoin {
 	MidgardObjectClass *klass;
 	gchar *left_table;
 	gchar *left_field;
+	MidgardObjectClass *left_klass;
 	gchar *right_table;
 	gchar *right_field;
+	MidgardObjectClass *right_klass;
 	gchar *left_tablefield;
 	gchar *right_tablefield;
 
@@ -227,6 +229,11 @@ guint midgard_core_query_get_id(
 			const gchar *table,
 			const gchar *guid);
 
+guint* midgard_core_query_get_tree_ids(
+			MidgardConnection *mgd,
+			MidgardObjectClass *klass,
+			guint tid);
+
 gint midgard_core_query_insert_records(
 			MidgardConnection *mgd,
 			const gchar *table, 
