@@ -72,36 +72,42 @@ void midgard_query_builder_private_free(MidgardQueryBuilderPrivate *mqbp)
 		if(list->data != NULL && G_IS_OBJECT(list->data))
 			g_object_unref(G_OBJECT(list->data));
 	}
-	if(list)
-		g_slist_free(list);
-	list = NULL;
+	if(mqbp->constraints) {		
+		g_slist_free(mqbp->constraints);
+		mqbp->constraints = NULL;
+	}
 
 	/* free groups */
 	for(list = mqbp->groups; list != NULL; list = list->next) {
 		g_object_unref(list->data);
 	}
-	if(list)
-		g_slist_free(list);
-	list = NULL;
+	if(mqbp->groups) {
+		g_slist_free(mqbp->groups);
+		mqbp->groups = NULL;
+	}
 
 	/* free orders */
 	for(list = mqbp->orders; list != NULL; list = list->next) {
 		midgard_core_query_order_free((MidgardQueryOrder *)list->data);
 	}
-	if(list)
-		g_slist_free(list);
-	list = NULL;
-
+	if(mqbp->orders) {
+		g_slist_free(mqbp->orders);
+		mqbp->orders = NULL;
+	}
+	
 	/* free joins */
 	for(list = mqbp->joins; list != NULL; list = list->next) {
 		midgard_core_query_constraint_private_free((MidgardCoreQueryConstraintPrivate*) list->data);
 	}
-	if(list)
-		g_slist_free(list);
+	if(mqbp->joins) {
+		g_slist_free(mqbp->joins);
+		mqbp->joins = NULL;
+	}
 	list = NULL;
 
 	/* free tables */
 	g_hash_table_destroy(mqbp->tables);
+	mqbp->tables = NULL;
 
 	/* free itself */
 	g_free(mqbp);
@@ -124,7 +130,7 @@ void midgard_core_qb_add_constraint(MidgardQueryBuilder *builder,
 	g_assert(constraint != NULL);
 
 	builder->priv->constraints = 
-		g_slist_append(builder->priv->constraints, constraint);	
+		g_slist_append(builder->priv->constraints, constraint);
 }
 
 void midgard_core_qb_add_order(MidgardQueryBuilder *builder,
@@ -284,14 +290,15 @@ gchar *midgard_core_qb_get_sql(
 
 	MidgardDBObjectClass *dbklass = g_type_class_peek(builder->priv->type);
 
-	if (dbklass->dbpriv->has_metadata) {
-	
-		if(!builder->priv->include_deleted) {
-	
+	if(!builder->priv->include_deleted) {
+
+		const gchar *deleted_field = midgard_core_object_get_deleted_field (dbklass);	
+		if (deleted_field) {
 			g_string_append(sql, " AND ");
 			g_string_append_printf(sql,
-					" %s.metadata_deleted = 0",
-					builder->priv->schema->table);
+					" %s.%s = 0",
+					builder->priv->schema->table, 
+					deleted_field);
 		}
 	}
 
@@ -353,8 +360,7 @@ static void __join_reference(MidgardQueryBuilder *builder, const gchar *src_tabl
 	MidgardCoreQueryConstraint *dc = midgard_core_query_constraint_new();
 	GString *dstr = g_string_new("");
 	g_string_append_printf(dstr,"%s.metadata_deleted = 0", ref_table);
-	dc->priv->condition = g_strdup(dstr->str);
-	g_string_free(dstr, TRUE);
+	dc->priv->condition = g_string_free(dstr, FALSE);
 	
 	midgard_core_qb_add_constraint(builder,dc);
 	
@@ -672,9 +678,9 @@ GObject **midgard_core_qb_execute(MidgardQueryBuilder *builder, guint *n_objects
 	*n_objects = g_list_length(list);
 	MidgardObject **objects = g_new(MidgardObject *, *n_objects+1);
 
-	for( ; list; list = list->next){
-
-		objects[i] = list->data;
+	GList *l = NULL;
+	for(l = list; l != NULL; l = l->next) {
+		objects[i] = l->data;
 		i++;
 	}
 
