@@ -56,6 +56,7 @@ midgard_core_schema_type_property_attr_new_empty (void)
 	prop->is_unique = FALSE;
 	prop->description = NULL;
 	prop->user_values = NULL;
+	prop->derived = NULL;
 
 	return prop;
 }
@@ -161,6 +162,8 @@ midgard_core_schema_type_property_attr_free (MgdSchemaPropertyAttr *prop)
 	g_hash_table_destroy(prop->user_values);
 	prop->user_values = NULL;
 
+	prop->derived = NULL;
+
 	g_free (prop);
 
 	prop = NULL;
@@ -177,6 +180,7 @@ midgard_core_schema_type_attr_new (void)
 	type->params = NULL;
 	type->properties = NULL;
 	type->table = NULL;
+	type->view_table = NULL;
 	type->parentfield = NULL;
 	type->upfield = NULL;
 	type->primaryfield = NULL;
@@ -266,6 +270,9 @@ midgard_core_schema_type_attr_free (MgdSchemaTypeAttr *type)
 	g_free ((gchar *)type->table);
 	type->table = NULL;
 
+	g_free ((gchar *)type->view_table);
+	type->view_table = NULL;
+
 	g_free ((gchar *)type->tables);
 	type->tables = NULL;
 
@@ -628,7 +635,8 @@ midgard_core_schema_type_build_static_sql (MgdSchemaTypeAttr *type_attr)
 	if (_sql->str == NULL)
 		return;
 
-	type_attr->sql_select_full = g_string_free (_sql, FALSE);
+	g_string_free (_sql, TRUE);
+	/* type_attr->sql_select_full = g_string_free (_sql, FALSE); */
 }
 
 static void 
@@ -639,6 +647,10 @@ __field_is_equal(gpointer key, gpointer val, gpointer userdata)
 
 	if (!g_str_equal (prop_attr->name, src_prop->name)) {
 
+		if (prop_attr->tablefield == NULL
+				|| src_prop->tablefield == NULL)
+			return;
+
 		if (g_str_equal (prop_attr->tablefield, src_prop->tablefield)) {
 
 			g_warning ("Field %s redefined for %s and %s", 
