@@ -178,6 +178,8 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 	MgdSchemaPropertyAttr *propright = NULL;
 	MgdSchemaPropertyAttr *propleft = NULL;
 	MidgardDBObjectClass *metadata_klass = MIDGARD_DBOBJECT_CLASS (g_type_class_peek (MIDGARD_TYPE_METADATA));
+	MidgardObjectClass *left_klass = NULL;
+	MidgardObjectClass *right_klass = NULL;
 	gchar *left_table = NULL;
 	gchar *right_table = NULL;
 	gchar *left_field = NULL;
@@ -266,6 +268,7 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 				left_table = g_strdup (propleft->table ? propleft->table : type->table);
 				left_field = g_strdup (propleft->field);
 			}
+			left_klass = MIDGARD_OBJECT_CLASS (klass);
 			g_strfreev(classprop);	
 
 			/* Get right property attribute */
@@ -297,6 +300,7 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 				right_table = g_strdup (propright->table ? propright->table : type->table);
 				right_field = g_strdup (propright->field);
 			}
+			right_klass = MIDGARD_OBJECT_CLASS (klass);
 			g_strfreev(classprop);
 
 			MidgardDBJoin *mdbj = midgard_core_dbjoin_new();
@@ -316,6 +320,9 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 			mdbj->right_table = right_table;
 			mdbj->right_field = right_field;
 
+			mdbj->left_klass = left_klass;
+			mdbj->right_klass = right_klass;
+
 			g_free(left);
 			g_free(right);
 
@@ -453,6 +460,58 @@ static void __mgdschematype_from_node(xmlNode *node, GSList **list)
 	xmlFree(viewname);
 }
 
+static gchar*
+__build_create_view_cmd (MidgardConnection *mgd, MidgardDBObjectClass *klass)
+{
+	guint n_props;
+	GParamSpec **pspecs = g_object_class_list_properties (G_OBJECT_CLASS (klass), &n_props);
+	GdaConnection *cnc = mgd->priv->connection;
+	MgdSchemaTypeAttr *type = midgard_core_class_get_type_attr (klass);
+
+	guint i;
+	GString *ssf = g_string_new ("");
+	gboolean add_coma = FALSE;
+	
+	for (i = 0; i < n_props; i++) {
+		
+		if (G_TYPE_FUNDAMENTAL (pspecs[i]->value_type) == G_TYPE_OBJECT) {
+			if (i == 1)
+				add_coma = FALSE;
+			continue;
+		}
+
+		/* Replace tablefield for every property */
+		MgdSchemaPropertyAttr *prop_attr = g_hash_table_lookup (type->prophash, pspecs[i]->name);
+		if (!prop_attr) {
+			g_warning ("%s property not registered for %s", pspecs[i]->name, type->name);
+			g_error ("Failed to register view class");
+		}
+
+		gchar *q_table = gda_connection_quote_sql_identifier (cnc, 
+				prop_attr->derived->table ? prop_attr->derived->table : prop_attr->table);
+		gchar *q_field = gda_connection_quote_sql_identifier (cnc, prop_attr->derived->field);
+		gchar *q_name = gda_connection_quote_sql_identifier (cnc, pspecs[i]->name);
+
+		g_string_append_printf (ssf, "%s%s.%s AS %s", 
+				add_coma ? ", " : " ",
+				q_table, q_field, q_name);
+		
+		gchar *t_table = gda_connection_quote_sql_identifier (cnc, type->name);	
+		midgard_core_schema_type_property_set_tablefield (prop_attr, t_table, q_name);
+	
+		g_free (q_table);
+		g_free (q_field); 
+		g_free (q_name);
+		g_free (t_table);
+
+		add_coma = TRUE;
+	}
+	
+	g_free (pspecs);
+
+	return g_string_free (ssf, FALSE);
+}
+
 gchar *
 midgard_core_view_build_create_view_command (MidgardConnection *mgd, MidgardDBObjectClass *klass)
 {
@@ -460,10 +519,10 @@ midgard_core_view_build_create_view_command (MidgardConnection *mgd, MidgardDBOb
 	GString *query = g_string_new ("CREATE VIEW ");	
 	MgdSchemaTypeAttr *type = midgard_core_class_get_type_attr (klass);
 
-	klass->dbpriv->set_static_sql_select (mgd, klass);
-
+	gchar *create_view_cmd = __build_create_view_cmd (mgd, klass);	
 	g_string_append_printf (query, "%s AS SELECT %s FROM %s ", 
-			type->name, (gchar *)type->sql_select_full, type->view_table);
+			type->name, create_view_cmd, type->view_table);
+	g_free (create_view_cmd);
 
 	GSList *list = NULL;
 
@@ -496,22 +555,40 @@ midgard_core_view_build_create_view_command (MidgardConnection *mgd, MidgardDBOb
 	guint i = 0;
 	g_string_append(query, " WHERE ");
 
-	if (!type->joins)
-		g_string_append_printf (query, " %s.metadata_deleted = 0 ", type->table);
+	MidgardDBObjectClass *dbklass = NULL;
+	const gchar *deleted_field = NULL;
+	GSList *dellist = NULL;
+
+	if (!type->joins) {
+		dbklass = MIDGARD_DBOBJECT_CLASS (g_type_class_peek (g_type_from_name (type->name)));
+		deleted_field = midgard_core_object_get_deleted_field (dbklass);
+		if (deleted_field)
+			dellist = g_slist_prepend (dellist, 
+					g_strdup_printf ("%s.%s = 0", type->table, deleted_field));
+	}
 
 	for (list = type->joins; list != NULL; list = list->next) {
 		
-		if(i > 0)
-			g_string_append(query, " AND ");
-
 		MidgardDBJoin *join = (MidgardDBJoin *) list->data;
-		g_string_append_printf(query, " %s.metadata_deleted = 0 AND %s.metadata_deleted = 0 ", 
-				join->left_table ? join->left_table : join->left->table, 
-				join->right_table ? join->right_table : join->right->table);
-
-		i++;
+		deleted_field = midgard_core_object_get_deleted_field (MIDGARD_DBOBJECT_CLASS (join->left_klass));
+		if (deleted_field)
+			dellist = g_slist_prepend (dellist, 
+					g_strdup_printf ("%s.%s = 0", join->left_table ? join->left_table : join->left->table, deleted_field));
+		deleted_field = midgard_core_object_get_deleted_field (MIDGARD_DBOBJECT_CLASS (join->right_klass));
+		if (deleted_field)
+			dellist = g_slist_prepend (dellist, 
+					g_strdup_printf ("%s.%s = 0", join->right_table ? join->right_table : join->right->table, deleted_field));
 	}
 
+	i = 0;
+	if (dellist)
+		dellist = g_slist_reverse (dellist);
+	for (list = dellist; list != NULL; list = list->next, i++) {
+		gchar *dc = (gchar*) list->data;
+		g_string_append_printf (query, " %s %s ", i > 0 ? "AND" : "", dc);
+		g_free (list->data);
+	}
+	g_slist_free (dellist);
 
 	list = NULL;
 	i = 0;
