@@ -1023,7 +1023,7 @@ static void __set_from_sql(MidgardDBObject *object,
  * Sets person property and updates user storage record.
  *
  * #MidgardUser @self takes ownership of the given #MidgardPerson reference, 
- * which should be not unref any more.
+ * and increases person's object reference count. 
  * 
  * See midgard_user_update() for returned error details.
  *
@@ -1041,7 +1041,9 @@ midgard_user_set_person (MidgardUser *self, MidgardObject *person)
 
 	g_return_val_if_fail (MGD_OBJECT_GUID (person) != NULL, FALSE);	
 
-	self->priv->person = person;
+	if (G_IS_OBJECT (self->priv->person))
+		g_object_unref (self->priv->person);
+	self->priv->person = g_object_ref (person);
 	g_free (self->priv->person_guid);
 	self->priv->person_guid = g_strdup (MGD_OBJECT_GUID (person));
 
@@ -1054,7 +1056,7 @@ midgard_user_set_person (MidgardUser *self, MidgardObject *person)
  *
  * Returned object should not be unref.
  *
- * Returns: #MidgardObject of "midgard_person" type, of %NULL if none associated.
+ * Returns: (transfer none): #MidgardObject of "midgard_person" type, or %NULL if none associated.
  */
 MidgardObject *
 midgard_user_get_person (MidgardUser *self)
@@ -1192,13 +1194,14 @@ _midgard_user_set_property (GObject *object, guint property_id,
 			break;
 
 		case MIDGARD_USER_TYPE:
-			if (g_value_get_uint (value) < MIDGARD_USER_TYPE_ADMIN) {
-				
-				self->priv->user_type = g_value_get_uint (value);
+			if (g_value_get_uint (value) > MIDGARD_USER_TYPE_ADMIN
+					|| g_value_get_uint (value) < MIDGARD_USER_TYPE_NONE) {
+	
+				g_warning ("Invalid user type (%d).", g_value_get_uint (value));
 
 			} else {
 
-				g_warning ("Invalid user type");
+				self->priv->user_type = g_value_get_uint (value);	
 			}
 			break;
 	
