@@ -637,8 +637,7 @@ GObject **midgard_query_builder_execute(
 
         list = midgard_query_builder_execute_or_count(builder, holder, MQB_SELECT_OBJECT);
 	
-	if(list == NULL) {
-		
+	if(list == NULL) {	
 		g_free(holder);
 		return NULL;
 	}
@@ -646,8 +645,9 @@ GObject **midgard_query_builder_execute(
 	*n_objects = holder->elements;
 	MidgardObject **objects = g_new(MidgardObject *, holder->elements+1);	
 
-	for( ; list; list = list->next){
-		objects[i] = list->data;
+	GList *l = NULL;
+	for(l = list; l != NULL; l = l->next){
+		objects[i] = l->data;
 		i++;
 	}	
 	objects[i] = NULL; /* Terminate by NULL */
@@ -1132,7 +1132,11 @@ midgard_query_builder_get_type_name (MidgardQueryBuilder *builder)
  * midgard_query_builder_include_deleted:
  * @builder: #MidgardQueryBuilder instance
  * 
- * Query all objects, deleted and undeleted. 
+ * Query all objects - deleted and undeleted.
+ *
+ * This is valid for a class for which metadata is defined ('deleted' property
+ * of MidgardMetadata class), or class has 'metadata' property installed. 
+ * If none of them is found, this method does nothing.
  */ 
 void 
 midgard_query_builder_include_deleted (MidgardQueryBuilder *builder)
